import 'dart:async';
import 'package:flutter/material.dart';
import 'package:flutter_picker_plus/flutter_picker_plus.dart';
import 'package:flutter_riverpod/flutter_riverpod.dart';
import 'package:signage_app/const/config.dart';
import 'package:signage_app/const/dimens.dart';
import 'package:signage_app/widget/display_date.dart';
import 'package:signage_app/widget/display_time.dart';
import 'package:signage_app/widget/information.dart';
import 'package:signage_app/widget/scroll_text.dart';
import 'package:signage_app/provider.dart';

class Footer extends ConsumerStatefulWidget {
  const Footer(
      {super.key, this.size = const Size(double.infinity, double.infinity)});

  final Size size;

  @override
  FooterState createState() => FooterState();
}

class FooterState extends ConsumerState<Footer> {
  bool _isSelectDateTime = false;
  bool _isShowColon = false;
  DateTime _setDateTime = DateTime.now();
  DateTime _prevDateTime = DateTime.now();
  late Timer _timer;

  @override
  void initState() {
    super.initState();

    _timer = Timer.periodic(
      const Duration(seconds: intervalUpdateTime),
      (timer) {
        if (_prevDateTime.minute != DateTime.now().minute) {
          _prevDateTime = DateTime.now();
          if (!_isSelectDateTime) {
            ref.watch(presentDateTimeProvider.notifier).state = DateTime.now();
          } else {
            _setDateTime =
                _setDateTime.add(const Duration(seconds: intervalUpdateTime));
            ref.watch(presentDateTimeProvider.notifier).state = _setDateTime;
          }
        }
        ref.watch(isShowColonProvider.notifier).state = _isShowColon;
        _isShowColon = !_isShowColon;
      },
    );
  }

  @override
  void dispose() {
    _timer.cancel();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    final Size widgetSize = MediaQuery.of(context).size;
    int touchCount = 0;
    Timer countTimer = Timer.periodic(
        const Duration(seconds: touchCountDuration),
        ((timer) => touchCount = 0));

    return SizedBox(
      height: widget.size.height,
      width: widget.size.width,
      child: Column(
        children: [
          GestureDetector(
            onSecondaryTap: () {
              countTimer.cancel();
              touchCount++;
              countTimer = Timer.periodic(
                  const Duration(seconds: touchCountDuration),
                  ((timer) => touchCount = 0));
              if (touchCount >= touchCountToSelectTime) {
                selectTime();
              }
            },
            child: Row(
              children: [
                DisplayTime(
                  size: Size(widgetSize.width * timeWidthRatio,
                      widgetSize.height * dateAndTimeHeightRatio),
                ),
                Expanded(
                  child: SizedBox(
                    height: widgetSize.height * dateAndTimeHeightRatio,
                    child: Stack(
                      children: [
                        DisplayDate(
                          size: Size(double.infinity,
                              widgetSize.height * dateAndTimeHeightRatio),
                        ),
                        Align(
                          alignment: Alignment.bottomRight,
                          child: Information(
                            size: Size(widgetSize.width * informationWidthRatio,
                                widgetSize.height * informationHeightRatio),
                          ),
                        ),
                      ],
                    ),
                  ),
                ),
              ],
            ),
          ),
          const Expanded(child: ScrollText()),
        ],
      ),
    );
  }

  Future<List<int>?> selectTime() {
    return Picker(
      adapter: DateTimePickerAdapter(
        type: PickerDateTimeType.kYMDHM,
        value: _setDateTime,
      ),
      title: const Text("Select Time"),
      onConfirm: (Picker picker, List<int> selected) => setState(
        () {
          _setDateTime = DateTime(1900 + selected[0], 1 + selected[1],
              1 + selected[2], selected[3], selected[4]);
          _isSelectDateTime = true;
        },
      ),
    ).showDialog(context);
  }
}
