import 'dart:async';
import 'dart:io';
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:signage_app/const/config.dart';

class WeatherImage extends StatefulWidget {
  const WeatherImage(
      {super.key, this.size = const Size(double.infinity, double.infinity)});

  final Size size;

  @override
  WeatherImageState createState() => WeatherImageState();
}

class WeatherImageState extends State<WeatherImage> {
  late List<String> imageFiles = [];
  late Timer _timer;
  int _showImageIndex = 0;

  @override
  void initState() {
    super.initState();
    Future(() async {
      imageFiles = await _getImageFiles();
      setState(
        () {},
      );
    });

    _timer = Timer.periodic(
      const Duration(seconds: intervalSwitchImage),
      (timer) {
        setState(
          () {
            _showImageIndex++;
            if (_showImageIndex >= imageFiles.length) {
              _showImageIndex = 0;
            }
          },
        );
      },
    );
  }

  @override
  void dispose() {
    _timer.cancel();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    imageFiles.sort((a, b) => a.compareTo(b));
    return SizedBox(
        height: widget.size.height,
        width: widget.size.width,
        child: AnimatedSwitcher(
          duration: const Duration(seconds: timeFadeImage),
          child: imageFiles.isEmpty
              ? Image.asset(
                  key: const Key('init'),
                  fit: BoxFit.fill,
                  initWeatherImage,
                )
              : Image.asset(
                  key: Key(imageFiles[_showImageIndex]),
                  fit: BoxFit.fill,
                  imageFiles[_showImageIndex],
                ),
        ));
  }

  Future<List<String>> _getImageFiles() async {
    Directory imageDir;
    final List<String> imageFiles = [];
    // Find assets/image in the Armadillo's container
    imageDir = Directory('/vol_app/data/flutter_assets/assets/image');
    // If Armadillo's assets/image does not exist, change to PC
    if (!imageDir.existsSync()) {
      imageDir = Directory('assets/image');
    }
    imageDir.list().listen(
      (FileSystemEntity entity) {
        imageFiles.add(entity.path);
      },
    );
    return imageFiles;
  }
}
